@@ -327,14 +327,26 @@ void ConstVisitor::apply(const block128Array& value)
 //
 // Array2Ds
 //
+void ConstVisitor::apply(const byteArray2D& value)
+{
+    apply(static_cast<const Data&>(value));
+}
 void ConstVisitor::apply(const ubyteArray2D& value)
 {
     apply(static_cast<const Data&>(value));
 }
+void ConstVisitor::apply(const shortArray2D& value)
+{
+    apply(static_cast<const Data&>(value));
+}
 void ConstVisitor::apply(const ushortArray2D& value)
 {
     apply(static_cast<const Data&>(value));
 }
+void ConstVisitor::apply(const intArray2D& value)
+{
+    apply(static_cast<const Data&>(value));
+}
 void ConstVisitor::apply(const uintArray2D& value)
 {
     apply(static_cast<const Data&>(value));
@@ -456,14 +468,26 @@ void ConstVisitor::apply(const block128Array2D& value)
 //
 // Array3Ds
 //
+void ConstVisitor::apply(const byteArray3D& value)
+{
+    apply(static_cast<const Data&>(value));
+}
 void ConstVisitor::apply(const ubyteArray3D& value)
 {
     apply(static_cast<const Data&>(value));
 }
+void ConstVisitor::apply(const shortArray3D& value)
+{
+    apply(static_cast<const Data&>(value));
+}
 void ConstVisitor::apply(const ushortArray3D& value)
 {
     apply(static_cast<const Data&>(value));
 }
+void ConstVisitor::apply(const intArray3D& value)
+{
+    apply(static_cast<const Data&>(value));
+}
 void ConstVisitor::apply(const uintArray3D& value)
 {
     apply(static_cast<const Data&>(value));
@@ -573,6 +597,10 @@ void ConstVisitor::apply(const MatrixTransform& value)
 {
     apply(static_cast<const Transform&>(value));
 }
+void ConstVisitor::apply(const CoordinateFrame& value)
+{
+    apply(static_cast<const Transform&>(value));
+}
 void ConstVisitor::apply(const Geometry& value)
 {
     apply(static_cast<const Command&>(value));
@@ -679,6 +707,10 @@ void ConstVisitor::apply(const TransformSampler& sampler)
 {
     apply(static_cast<const AnimationSampler&>(sampler));
 }
+void ConstVisitor::apply(const CameraSampler& sampler)
+{
+    apply(static_cast<const AnimationSampler&>(sampler));
+}
 void ConstVisitor::apply(const Joint& value)
 {
     apply(static_cast<const Node&>(value));
@@ -1028,6 +1060,10 @@ void ConstVisitor::apply(const LookAt& value)
 {
     apply(static_cast<const ViewMatrix&>(value));
 }
+void ConstVisitor::apply(const LookDirection& value)
+{
+    apply(static_cast<const ViewMatrix&>(value));
+}
 void ConstVisitor::apply(const RelativeViewMatrix& value)
 {
     apply(static_cast<const ViewMatrix&>(value));
